@@ -18,6 +18,7 @@
  */
 package org.sleuthkit.datamodel;
 
+import java.nio.file.Paths;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -238,13 +239,15 @@ public class CommunicationsManagerTest {
 	@BeforeClass
 	public static void setUpClass() {
 		String tempDirPath = System.getProperty("java.io.tmpdir");
-		tempDirPath = tempDirPath.substring(0, tempDirPath.length() - 1);
 		try {
-			dbPath = tempDirPath + java.io.File.separator + TEST_DB;
+			dbPath = Paths.get(tempDirPath, TEST_DB).toString();
 
 			// Delete the DB file, in case 
 			java.io.File dbFile = new java.io.File(dbPath);
 			dbFile.delete();
+			if (dbFile.getParentFile() != null) {
+				dbFile.getParentFile().mkdirs();
+			}
 
 			// Create new case db
 			caseDB = SleuthkitCase.newCase(dbPath);
@@ -1405,8 +1408,7 @@ public class CommunicationsManagerTest {
 
 		try {
 			// Add Email artifact
-			bbart = abstractFile.newArtifact(TSK_EMAIL_MSG);
-			bbart.addAttributes(bbattributes);
+			bbart = abstractFile.newDataArtifact(new BlackboardArtifact.Type(BlackboardArtifact.ARTIFACT_TYPE.TSK_EMAIL_MSG), bbattributes);
 
 			// Add account relationships
 			commsMgr.addRelationships(senderAccountInstance, recipientAccountInstances, bbart, MESSAGE, dateSent);
@@ -1460,17 +1462,20 @@ public class CommunicationsManagerTest {
 	private static void addCalllogArtifact(AccountFileInstance deviceAccount, String name, String phoneNumber, long date, long duration, String direction, AbstractFile abstractFile) {
 
 		try {
-			BlackboardArtifact bbart = abstractFile.newArtifact(TSK_CALLLOG); //create a call log and then add attributes from result set.
-			if (direction.equalsIgnoreCase("outgoing")) { //NON-NLS
-				bbart.addAttribute(new BlackboardAttribute(TSK_PHONE_NUMBER_TO, MODULE_NAME, phoneNumber));
-			} else { /// Covers INCOMING and MISSED
-				bbart.addAttribute(new BlackboardAttribute(TSK_PHONE_NUMBER_FROM, MODULE_NAME, phoneNumber));
-			}
-			bbart.addAttribute(new BlackboardAttribute(TSK_DATETIME_START, MODULE_NAME, date));
-			bbart.addAttribute(new BlackboardAttribute(TSK_DATETIME_END, MODULE_NAME, duration + date));
-			bbart.addAttribute(new BlackboardAttribute(TSK_DIRECTION, MODULE_NAME, direction));
-			bbart.addAttribute(new BlackboardAttribute(TSK_NAME, MODULE_NAME, name));
 
+			BlackboardAttribute attrPhonToOrFrom = direction.equalsIgnoreCase("outgoing")
+					? new BlackboardAttribute(TSK_PHONE_NUMBER_TO, MODULE_NAME, phoneNumber)
+					: new BlackboardAttribute(TSK_PHONE_NUMBER_FROM, MODULE_NAME, phoneNumber);
+
+			Collection<BlackboardAttribute> attributes = Arrays.asList(
+					attrPhonToOrFrom,
+					new BlackboardAttribute(TSK_DATETIME_START, MODULE_NAME, date),
+					new BlackboardAttribute(TSK_DATETIME_END, MODULE_NAME, duration + date),
+					new BlackboardAttribute(TSK_DIRECTION, MODULE_NAME, direction),
+					new BlackboardAttribute(TSK_NAME, MODULE_NAME, name)
+			);
+
+			BlackboardArtifact bbart = abstractFile.newDataArtifact(new BlackboardArtifact.Type(BlackboardArtifact.ARTIFACT_TYPE.TSK_CALLLOG), attributes); //create a call log and then add attributes from result set.
 			// Create a phone number account for the phone number
 			AccountFileInstance phoneNumAccount = commsMgr.createAccountFileInstance(PHONE, phoneNumber, MODULE_NAME, abstractFile);
 			List<AccountFileInstance> accountInstanceList = new ArrayList<AccountFileInstance>();
@@ -1489,19 +1494,21 @@ public class CommunicationsManagerTest {
 	private static void addMessageArtifact(AccountFileInstance deviceAccount, String phoneNumber, long date, String direction, String subject, String message, AbstractFile abstractFile) {
 
 		try {
-			BlackboardArtifact bbart = abstractFile.newArtifact(TSK_MESSAGE); //create Message artifact and then add attributes from result set.
+			BlackboardAttribute attrPhoneToOrFrom = (direction.equalsIgnoreCase("incoming"))
+					? new BlackboardAttribute(TSK_PHONE_NUMBER_FROM, MODULE_NAME, phoneNumber)
+					: new BlackboardAttribute(TSK_PHONE_NUMBER_TO, MODULE_NAME, phoneNumber);
 
-			if (direction.equalsIgnoreCase("incoming")) {
-				bbart.addAttribute(new BlackboardAttribute(TSK_PHONE_NUMBER_FROM, MODULE_NAME, phoneNumber));
-			} else {
-				bbart.addAttribute(new BlackboardAttribute(TSK_PHONE_NUMBER_TO, MODULE_NAME, phoneNumber));
-			}
+			Collection<BlackboardAttribute> attributes = Arrays.asList(
+					attrPhoneToOrFrom,
+					new BlackboardAttribute(TSK_DIRECTION, MODULE_NAME, direction),
+					new BlackboardAttribute(TSK_DATETIME, MODULE_NAME, date),
+					new BlackboardAttribute(TSK_SUBJECT, MODULE_NAME, subject),
+					new BlackboardAttribute(TSK_TEXT, MODULE_NAME, message),
+					new BlackboardAttribute(TSK_MESSAGE_TYPE, MODULE_NAME, "SMS")
+			);
 
-			bbart.addAttribute(new BlackboardAttribute(TSK_DIRECTION, MODULE_NAME, direction));
-			bbart.addAttribute(new BlackboardAttribute(TSK_DATETIME, MODULE_NAME, date));
-			bbart.addAttribute(new BlackboardAttribute(TSK_SUBJECT, MODULE_NAME, subject));
-			bbart.addAttribute(new BlackboardAttribute(TSK_TEXT, MODULE_NAME, message));
-			bbart.addAttribute(new BlackboardAttribute(TSK_MESSAGE_TYPE, MODULE_NAME, "SMS"));
+			//create Message artifact and then add attributes from result set.
+			BlackboardArtifact bbart = abstractFile.newDataArtifact(new BlackboardArtifact.Type(BlackboardArtifact.ARTIFACT_TYPE.TSK_MESSAGE), attributes);
 
 			// Create a phone number account for the phone number
 			AccountFileInstance phoneNumAccount = commsMgr.createAccountFileInstance(PHONE, phoneNumber, MODULE_NAME, abstractFile);
@@ -1521,12 +1528,14 @@ public class CommunicationsManagerTest {
 	private static void addContactArtifact(AccountFileInstance deviceAccount, String name, String phoneNumber, String emailAddr, AbstractFile abstractFile) {
 
 		try {
-			BlackboardArtifact bbart = abstractFile.newArtifact(TSK_CONTACT); // create a CONTACT artifact
+			Collection<BlackboardAttribute> attributes = Arrays.asList(
+					new BlackboardAttribute(TSK_NAME, MODULE_NAME, name),
+					new BlackboardAttribute(TSK_PHONE_NUMBER, MODULE_NAME, phoneNumber),
+					new BlackboardAttribute(TSK_EMAIL, MODULE_NAME, emailAddr)
+			);
 
-			bbart.addAttribute(new BlackboardAttribute(TSK_NAME, MODULE_NAME, name));
-
-			bbart.addAttribute(new BlackboardAttribute(TSK_PHONE_NUMBER, MODULE_NAME, phoneNumber));
-			bbart.addAttribute(new BlackboardAttribute(TSK_EMAIL, MODULE_NAME, emailAddr));
+			// create a CONTACT artifact
+			BlackboardArtifact bbart = abstractFile.newDataArtifact(new BlackboardArtifact.Type(BlackboardArtifact.ARTIFACT_TYPE.TSK_CONTACT), attributes);
 
 			// Create a phone number account for the phone number
 			AccountFileInstance phoneNumAccount = commsMgr.createAccountFileInstance(PHONE, phoneNumber, MODULE_NAME, abstractFile);
