@@ -7,8 +7,10 @@ import org.sleuthkit.datamodel.TagName.HTML_COLOR;
  */
 public class PublicTagName extends TagName {
 
-	public PublicTagName(long id, String displayName, String description, HTML_COLOR color, TskData.FileKnown knownStatus) {
-		super(id, displayName, description, color, knownStatus);
+	private static final long serialVersionUID = 1L;
+
+	public PublicTagName(long id, String displayName, String description, HTML_COLOR color, TskData.FileKnown knownStatus, long tagSetId, int rank) {
+		super(id, displayName, description, color, knownStatus, tagSetId, rank);
 	}
 
 	@Override
