@@ -1,7 +1,7 @@
 /*
  * Sleuth Kit CASE JSON LD Support
  *
- * Copyright 2020 Basis Technology Corp.
+ * Copyright 2020-2021 Basis Technology Corp.
  * Contact: carrier <at> sleuthkit <dot> org
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -34,4 +34,8 @@ class Contact extends Facet {
         this.contactName = contactName;
         return this;
     }
+
+    String getContactName() {
+        return contactName;
+    }
 }
