@@ -1,7 +1,7 @@
 /*
  * Sleuth Kit CASE JSON LD Support
  *
- * Copyright 2020 Basis Technology Corp.
+ * Copyright 2020-2021 Basis Technology Corp.
  * Contact: carrier <at> sleuthkit <dot> org
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -46,4 +46,12 @@ class OperatingSystem extends Facet {
         this.version = version;
         return this;
     }
+
+    String getInstallDate() {
+        return installDate;
+    }
+
+    String getVersion() {
+        return version;
+    }
 }
