@@ -17,6 +17,7 @@
 
 #include "tsk_img_i.h"
 #include "raw.h"
+#include "tsk/util/file_system_utils.h"
 
 #ifdef __APPLE__
 #include <sys/disk.h>
@@ -39,19 +40,7 @@
 #define S_IFDIR __S_IFDIR
 #endif
 
-/**
- * \internal
- * Test if the image is a Windows device
- * @param The path to test
- *
- * Return 1 if the path represents a Windows device, 0 otherwise
- */
-#ifdef TSK_WIN32
-static int
-is_windows_device_path(const TSK_TCHAR * image_name) {
-    return (TSTRNCMP(image_name, _TSK_T("\\\\.\\"), 4) == 0);
-}
-#endif
+
 
 /** 
  * \internal
@@ -239,7 +228,7 @@ raw_read_segment(IMG_RAW_INFO * raw_info, int idx, char *buf,
         // the number of bytes read
         if (sector_aligned_buf != NULL) {
             memcpy(buf, sector_aligned_buf + rel_offset % raw_info->img_info.sector_size, len);
-            cnt = cnt - offset_to_read % raw_info->img_info.sector_size;
+            cnt = cnt - rel_offset % raw_info->img_info.sector_size;
             if (cnt < 0) {
                 cnt = -1;
             }
@@ -475,173 +464,7 @@ raw_close(TSK_IMG_INFO * img_info)
 }
 
 
-/**
- * Get the size in bytes of the given file.
- *
- * @param a_file The file to test
- * @param is_winobj 1 if the file is a windows object and not a real file
- *
- * @return the size in bytes, or -1 on error/unknown,
- *         -2 if unreadable, -3 if it's a directory.
- */
-static TSK_OFF_T
-get_size(const TSK_TCHAR * a_file, uint8_t a_is_winobj)
-{
-    TSK_OFF_T size = -1;
-    struct STAT_STR sb;
 
-    if (TSTAT(a_file, &sb) < 0) {
-        if (a_is_winobj) {
-            /* stat can fail for Windows objects; ignore that */
-            if (tsk_verbose) {
-                tsk_fprintf(stderr,
-                    "raw_open: ignoring stat result on Windows device %"
-                    PRIttocTSK "\n", a_file);
-            }
-        }
-        else {
-            tsk_error_reset();
-            tsk_error_set_errno(TSK_ERR_IMG_STAT);
-            tsk_error_set_errstr("raw_open: image \"%" PRIttocTSK
-                "\" - %s", a_file, strerror(errno));
-            return -2;
-        }
-    }
-    else if ((sb.st_mode & S_IFMT) == S_IFDIR) {
-        tsk_error_reset();
-        tsk_error_set_errno(TSK_ERR_IMG_MAGIC);
-        tsk_error_set_errstr("raw_open: image \"%" PRIttocTSK
-            "\" - is a directory", a_file);
-        return -3;
-    }
-
-#ifdef TSK_WIN32
-    {
-        HANDLE fd;
-        DWORD dwHi, dwLo;
-
-        if ((fd = CreateFile(a_file, FILE_READ_DATA,
-                    FILE_SHARE_READ | FILE_SHARE_WRITE, NULL, 
-                    OPEN_EXISTING, 0, NULL)) ==
-            INVALID_HANDLE_VALUE) {
-            int lastError = (int)GetLastError();
-            tsk_error_reset();
-            tsk_error_set_errno(TSK_ERR_IMG_OPEN);
-            // print string of commonly found errors
-            if (lastError == ERROR_ACCESS_DENIED) {
-                tsk_error_set_errstr("raw_open: file \"%" PRIttocTSK
-                    "\" - access denied", a_file);
-            }
-            else if (lastError == ERROR_SHARING_VIOLATION) {
-                tsk_error_set_errstr("raw_open: file \"%" PRIttocTSK
-                    "\" - sharing violation", a_file);
-            }
-            else if (lastError == ERROR_FILE_NOT_FOUND) {
-                tsk_error_set_errstr("raw_open: file \"%" PRIttocTSK
-                    "\" - file not found", a_file);
-            }
-            else {
-                tsk_error_set_errstr("raw_open: file \"%" PRIttocTSK
-                    "\" - (error %d)", a_file, lastError);
-            }
-            return -2;
-        }
-
-        /* We need different techniques to determine the size of Windows physical
-         * devices versus normal files */
-        if (a_is_winobj == 0) {
-            dwLo = GetFileSize(fd, &dwHi);
-            if (dwLo == 0xffffffff) {
-                int lastError = (int)GetLastError();
-                tsk_error_reset();
-                tsk_error_set_errno(TSK_ERR_IMG_OPEN);
-                tsk_error_set_errstr("raw_open: file \"%" PRIttocTSK
-                    "\" - GetFileSize: %d", a_file, lastError);
-                size = -1;
-            }
-            else {
-                size = dwLo | ((TSK_OFF_T) dwHi << 32);
-            }
-        }
-        else {
-            
-            //use GET_PARTITION_INFO_EX prior to IOCTL_DISK_GET_DRIVE_GEOMETRY
-            // to determine the physical disk size because
-            //calculating it with the help of GET_DRIVE_GEOMETRY gives only
-            // approximate number
-            DWORD junk;
-            
-            PARTITION_INFORMATION_EX partition;
-            if (FALSE == DeviceIoControl(fd,
-                IOCTL_DISK_GET_PARTITION_INFO_EX,
-                NULL, 0, &partition, sizeof(partition), &junk,
-                (LPOVERLAPPED)NULL) )  {
-                DISK_GEOMETRY pdg;
-
-                if (FALSE == DeviceIoControl(fd, IOCTL_DISK_GET_DRIVE_GEOMETRY,
-                        NULL, 0, &pdg, sizeof(pdg), &junk, (LPOVERLAPPED) NULL)) {
-                    int lastError = (int)GetLastError();
-                    tsk_error_reset();
-                    tsk_error_set_errno(TSK_ERR_IMG_OPEN);
-                    tsk_error_set_errstr("raw_open: file \"%" PRIttocTSK
-                        "\" - DeviceIoControl: %d", a_file,
-                        lastError);
-                    size = -1;
-                }
-                else {
-                    size = pdg.Cylinders.QuadPart *
-                        (TSK_OFF_T) pdg.TracksPerCylinder *
-                        (TSK_OFF_T) pdg.SectorsPerTrack *
-                        (TSK_OFF_T) pdg.BytesPerSector;
-                }
-            }
-            else {
-                size = partition.PartitionLength.QuadPart;
-            }
-        }
-
-        CloseHandle(fd);
-    }
-#else
-
-    int fd;
-
-    if ((fd = open(a_file, O_RDONLY | O_BINARY)) < 0) {
-        tsk_error_reset();
-        tsk_error_set_errno(TSK_ERR_IMG_OPEN);
-        tsk_error_set_errstr("raw_open: file \"%" PRIttocTSK "\" - %s",
-            a_file, strerror(errno));
-        return -2;
-    }
-
-#ifdef __APPLE__
-    /* OS X doesn't support SEEK_END on char devices */
-    if ((sb.st_mode & S_IFMT) != S_IFCHR) {
-        size = lseek(fd, 0, SEEK_END);
-    }
-
-    if (size <= 0) {
-        int blkSize;
-        long long blkCnt;
-
-        if (ioctl(fd, DKIOCGETBLOCKSIZE, &blkSize) >= 0) {
-            if (ioctl(fd, DKIOCGETBLOCKCOUNT, &blkCnt) >= 0) {
-                size = blkCnt * (long long) blkSize;
-            }
-        }
-    }
-#else
-    /* We don't use the stat output because it doesn't work on raw
-     * devices and such */
-    size = lseek(fd, 0, SEEK_END);
-#endif
-
-    close(fd);
-
-#endif
-
-    return size;
-}
 
 #ifdef TSK_WIN32
 /**
@@ -800,7 +623,7 @@ raw_open(int a_num_img, const TSK_TCHAR * const a_images[],
 #endif
 
     /* Check that the first image file exists and is not a directory */
-    first_seg_size = get_size(a_images[0], raw_info->is_winobj);
+    first_seg_size = get_size_of_file_on_disk(a_images[0], raw_info->is_winobj);
     if (first_seg_size < -1) {
         tsk_img_free(raw_info);
         return NULL;
@@ -919,7 +742,7 @@ raw_open(int a_num_img, const TSK_TCHAR * const a_images[],
     for (i = 1; i < raw_info->img_info.num_img; i++) {
         TSK_OFF_T size;
         raw_info->cptr[i] = -1;
-        size = get_size(raw_info->img_info.images[i], raw_info->is_winobj);
+        size = get_size_of_file_on_disk(raw_info->img_info.images[i], raw_info->is_winobj);
         if (size < 0) {
             if (size == -1) {
                 if (tsk_verbose) {
